# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.token0_address_token1_address_pair_address.get import GetPairAddress
from openapi_evm_api.paths.pair_address_reserves.get import GetPairReserves


class DefiApi(
    GetPairAddress,
    GetPairReserves,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_streams
from openapi_streams.model.addresses_types_addresses_response import AddressesTypesAddressesResponse
from openapi_streams import configuration


class TestAddressesTypesAddressesResponse(unittest.TestCase):
    """AddressesTypesAddressesResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_sol_api
from openapi_sol_api.model.nft_metadata import NFTMetadata
from openapi_sol_api import configuration


class TestNFTMetadata(unittest.TestCase):
    """NFTMetadata unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



import json
from .api_instance import get_api_instance
import typing
from openapi_streams.paths.streams_evm_id_address.delete import RequestPathParams, SchemaForRequestBodyApplicationJson


def delete_address_from_stream(api_key: str, params: RequestPathParams, body: SchemaForRequestBodyApplicationJson):
    api_instance = get_api_instance(api_key)
    path_params = {k: v for k, v in params.items() if k in RequestPathParams.__annotations__.keys()}

    api_response = api_instance.delete_address_from_stream(
        body=body,
        path_params=path_params,
        accept_content_types='application/json; charset=utf-8',
        skip_deserialization=True
    )

    return json.loads(api_response.response.data)




import typing_extensions

from openapi_auth.paths import PathValues
from openapi_auth.apis.paths.challenge_request_evm import ChallengeRequestEvm
from openapi_auth.apis.paths.challenge_verify_evm import ChallengeVerifyEvm
from openapi_auth.apis.paths.challenge_request_solana import ChallengeRequestSolana
from openapi_auth.apis.paths.challenge_verify_solana import ChallengeVerifySolana

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.CHALLENGE_REQUEST_EVM: ChallengeRequestEvm,
        PathValues.CHALLENGE_VERIFY_EVM: ChallengeVerifyEvm,
        PathValues.CHALLENGE_REQUEST_SOLANA: ChallengeRequestSolana,
        PathValues.CHALLENGE_VERIFY_SOLANA: ChallengeVerifySolana,
    }
)

path_to_api = PathToApi(
    {
        PathValues.CHALLENGE_REQUEST_EVM: ChallengeRequestEvm,
        PathValues.CHALLENGE_VERIFY_EVM: ChallengeVerifyEvm,
        PathValues.CHALLENGE_REQUEST_SOLANA: ChallengeRequestSolana,
        PathValues.CHALLENGE_VERIFY_SOLANA: ChallengeVerifySolana,
    }
)



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class Transaction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "receiptGasUsed",
            "transactionIndex",
            "type",
            "nonce",
            "toAddress",
            "receiptRoot",
            "input",
            "r",
            "receiptCumulativeGasUsed",
            "s",
            "v",
            "gas",
            "fromAddress",
            "receiptContractAddress",
            "value",
            "hash",
            "receiptStatus",
            "gasPrice",
        }
        
        class properties:
            hash = schemas.StrSchema
            
            
            class gas(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'gas':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class gasPrice(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'gasPrice':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class nonce(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'nonce':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class input(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'input':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            transactionIndex = schemas.StrSchema
            fromAddress = schemas.StrSchema
            
            
            class toAddress(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'toAddress':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class value(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'value':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class type(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'type':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class v(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'v':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class r(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'r':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class s(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 's':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class receiptCumulativeGasUsed(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'receiptCumulativeGasUsed':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class receiptGasUsed(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'receiptGasUsed':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class receiptContractAddress(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'receiptContractAddress':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class receiptRoot(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'receiptRoot':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class receiptStatus(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'receiptStatus':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class triggers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['TriggerOutput']:
                        return TriggerOutput
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['TriggerOutput'], typing.List['TriggerOutput']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'triggers':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'TriggerOutput':
                    return super().__getitem__(i)
            __annotations__ = {
                "hash": hash,
                "gas": gas,
                "gasPrice": gasPrice,
                "nonce": nonce,
                "input": input,
                "transactionIndex": transactionIndex,
                "fromAddress": fromAddress,
                "toAddress": toAddress,
                "value": value,
                "type": type,
                "v": v,
                "r": r,
                "s": s,
                "receiptCumulativeGasUsed": receiptCumulativeGasUsed,
                "receiptGasUsed": receiptGasUsed,
                "receiptContractAddress": receiptContractAddress,
                "receiptRoot": receiptRoot,
                "receiptStatus": receiptStatus,
                "triggers": triggers,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    receiptGasUsed: MetaOapg.properties.receiptGasUsed
    transactionIndex: MetaOapg.properties.transactionIndex
    type: MetaOapg.properties.type
    nonce: MetaOapg.properties.nonce
    toAddress: MetaOapg.properties.toAddress
    receiptRoot: MetaOapg.properties.receiptRoot
    input: MetaOapg.properties.input
    r: MetaOapg.properties.r
    receiptCumulativeGasUsed: MetaOapg.properties.receiptCumulativeGasUsed
    s: MetaOapg.properties.s
    v: MetaOapg.properties.v
    gas: MetaOapg.properties.gas
    fromAddress: MetaOapg.properties.fromAddress
    receiptContractAddress: MetaOapg.properties.receiptContractAddress
    value: MetaOapg.properties.value
    hash: MetaOapg.properties.hash
    receiptStatus: MetaOapg.properties.receiptStatus
    gasPrice: MetaOapg.properties.gasPrice
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receiptGasUsed"]) -> MetaOapg.properties.receiptGasUsed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactionIndex"]) -> MetaOapg.properties.transactionIndex: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["toAddress"]) -> MetaOapg.properties.toAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receiptRoot"]) -> MetaOapg.properties.receiptRoot: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["input"]) -> MetaOapg.properties.input: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["r"]) -> MetaOapg.properties.r: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receiptCumulativeGasUsed"]) -> MetaOapg.properties.receiptCumulativeGasUsed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["s"]) -> MetaOapg.properties.s: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["v"]) -> MetaOapg.properties.v: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromAddress"]) -> MetaOapg.properties.fromAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receiptContractAddress"]) -> MetaOapg.properties.receiptContractAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receiptStatus"]) -> MetaOapg.properties.receiptStatus: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gasPrice"]) -> MetaOapg.properties.gasPrice: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["triggers"]) -> MetaOapg.properties.triggers: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["receiptGasUsed"], typing_extensions.Literal["transactionIndex"], typing_extensions.Literal["type"], typing_extensions.Literal["nonce"], typing_extensions.Literal["toAddress"], typing_extensions.Literal["receiptRoot"], typing_extensions.Literal["input"], typing_extensions.Literal["r"], typing_extensions.Literal["receiptCumulativeGasUsed"], typing_extensions.Literal["s"], typing_extensions.Literal["v"], typing_extensions.Literal["gas"], typing_extensions.Literal["fromAddress"], typing_extensions.Literal["receiptContractAddress"], typing_extensions.Literal["value"], typing_extensions.Literal["hash"], typing_extensions.Literal["receiptStatus"], typing_extensions.Literal["gasPrice"], typing_extensions.Literal["triggers"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receiptGasUsed"]) -> MetaOapg.properties.receiptGasUsed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactionIndex"]) -> MetaOapg.properties.transactionIndex: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["toAddress"]) -> MetaOapg.properties.toAddress: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receiptRoot"]) -> MetaOapg.properties.receiptRoot: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["input"]) -> MetaOapg.properties.input: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["r"]) -> MetaOapg.properties.r: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receiptCumulativeGasUsed"]) -> MetaOapg.properties.receiptCumulativeGasUsed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["s"]) -> MetaOapg.properties.s: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["v"]) -> MetaOapg.properties.v: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromAddress"]) -> MetaOapg.properties.fromAddress: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receiptContractAddress"]) -> MetaOapg.properties.receiptContractAddress: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receiptStatus"]) -> MetaOapg.properties.receiptStatus: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gasPrice"]) -> MetaOapg.properties.gasPrice: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["triggers"]) -> typing.Union[MetaOapg.properties.triggers, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["receiptGasUsed"], typing_extensions.Literal["transactionIndex"], typing_extensions.Literal["type"], typing_extensions.Literal["nonce"], typing_extensions.Literal["toAddress"], typing_extensions.Literal["receiptRoot"], typing_extensions.Literal["input"], typing_extensions.Literal["r"], typing_extensions.Literal["receiptCumulativeGasUsed"], typing_extensions.Literal["s"], typing_extensions.Literal["v"], typing_extensions.Literal["gas"], typing_extensions.Literal["fromAddress"], typing_extensions.Literal["receiptContractAddress"], typing_extensions.Literal["value"], typing_extensions.Literal["hash"], typing_extensions.Literal["receiptStatus"], typing_extensions.Literal["gasPrice"], typing_extensions.Literal["triggers"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        receiptGasUsed: typing.Union[MetaOapg.properties.receiptGasUsed, None, str, ],
        transactionIndex: typing.Union[MetaOapg.properties.transactionIndex, str, ],
        type: typing.Union[MetaOapg.properties.type, None, str, ],
        nonce: typing.Union[MetaOapg.properties.nonce, None, str, ],
        toAddress: typing.Union[MetaOapg.properties.toAddress, None, str, ],
        receiptRoot: typing.Union[MetaOapg.properties.receiptRoot, None, str, ],
        input: typing.Union[MetaOapg.properties.input, None, str, ],
        r: typing.Union[MetaOapg.properties.r, None, str, ],
        receiptCumulativeGasUsed: typing.Union[MetaOapg.properties.receiptCumulativeGasUsed, None, str, ],
        s: typing.Union[MetaOapg.properties.s, None, str, ],
        v: typing.Union[MetaOapg.properties.v, None, str, ],
        gas: typing.Union[MetaOapg.properties.gas, None, str, ],
        fromAddress: typing.Union[MetaOapg.properties.fromAddress, str, ],
        receiptContractAddress: typing.Union[MetaOapg.properties.receiptContractAddress, None, str, ],
        value: typing.Union[MetaOapg.properties.value, None, str, ],
        hash: typing.Union[MetaOapg.properties.hash, str, ],
        receiptStatus: typing.Union[MetaOapg.properties.receiptStatus, None, str, ],
        gasPrice: typing.Union[MetaOapg.properties.gasPrice, None, str, ],
        triggers: typing.Union[MetaOapg.properties.triggers, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Transaction':
        return super().__new__(
            cls,
            *_args,
            receiptGasUsed=receiptGasUsed,
            transactionIndex=transactionIndex,
            type=type,
            nonce=nonce,
            toAddress=toAddress,
            receiptRoot=receiptRoot,
            input=input,
            r=r,
            receiptCumulativeGasUsed=receiptCumulativeGasUsed,
            s=s,
            v=v,
            gas=gas,
            fromAddress=fromAddress,
            receiptContractAddress=receiptContractAddress,
            value=value,
            hash=hash,
            receiptStatus=receiptStatus,
            gasPrice=gasPrice,
            triggers=triggers,
            _configuration=_configuration,
        )

from openapi_streams.model.trigger_output import TriggerOutput



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class WebhookTypesIWebhookUnParsed(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "retries",
            "streamId",
            "chainId",
            "abi",
            "block",
            "txsInternal",
            "tag",
            "confirmed",
            "logs",
            "txs",
        }
        
        class properties:
        
            @staticmethod
            def block() -> typing.Type['Block']:
                return Block
            chainId = schemas.StrSchema
            
            
            class logs(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Log']:
                        return Log
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Log'], typing.List['Log']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'logs':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Log':
                    return super().__getitem__(i)
            
            
            class txs(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Transaction']:
                        return Transaction
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Transaction'], typing.List['Transaction']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'txs':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Transaction':
                    return super().__getitem__(i)
            
            
            class txsInternal(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['InternalTransaction']:
                        return InternalTransaction
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['InternalTransaction'], typing.List['InternalTransaction']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'txsInternal':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'InternalTransaction':
                    return super().__getitem__(i)
            
            
            class abi(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AbiItem']:
                        return AbiItem
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['AbiItem'], typing.List['AbiItem']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'abi':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'AbiItem':
                    return super().__getitem__(i)
            retries = schemas.Float64Schema
            confirmed = schemas.BoolSchema
            tag = schemas.StrSchema
            streamId = schemas.StrSchema
            __annotations__ = {
                "block": block,
                "chainId": chainId,
                "logs": logs,
                "txs": txs,
                "txsInternal": txsInternal,
                "abi": abi,
                "retries": retries,
                "confirmed": confirmed,
                "tag": tag,
                "streamId": streamId,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    retries: MetaOapg.properties.retries
    streamId: MetaOapg.properties.streamId
    chainId: MetaOapg.properties.chainId
    abi: MetaOapg.properties.abi
    block: 'Block'
    txsInternal: MetaOapg.properties.txsInternal
    tag: MetaOapg.properties.tag
    confirmed: MetaOapg.properties.confirmed
    logs: MetaOapg.properties.logs
    txs: MetaOapg.properties.txs
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chainId"]) -> MetaOapg.properties.chainId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["abi"]) -> MetaOapg.properties.abi: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block"]) -> 'Block': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["txsInternal"]) -> MetaOapg.properties.txsInternal: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["confirmed"]) -> MetaOapg.properties.confirmed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logs"]) -> MetaOapg.properties.logs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["txs"]) -> MetaOapg.properties.txs: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["retries"], typing_extensions.Literal["streamId"], typing_extensions.Literal["chainId"], typing_extensions.Literal["abi"], typing_extensions.Literal["block"], typing_extensions.Literal["txsInternal"], typing_extensions.Literal["tag"], typing_extensions.Literal["confirmed"], typing_extensions.Literal["logs"], typing_extensions.Literal["txs"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chainId"]) -> MetaOapg.properties.chainId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["abi"]) -> MetaOapg.properties.abi: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block"]) -> 'Block': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["txsInternal"]) -> MetaOapg.properties.txsInternal: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["confirmed"]) -> MetaOapg.properties.confirmed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logs"]) -> MetaOapg.properties.logs: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["txs"]) -> MetaOapg.properties.txs: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["retries"], typing_extensions.Literal["streamId"], typing_extensions.Literal["chainId"], typing_extensions.Literal["abi"], typing_extensions.Literal["block"], typing_extensions.Literal["txsInternal"], typing_extensions.Literal["tag"], typing_extensions.Literal["confirmed"], typing_extensions.Literal["logs"], typing_extensions.Literal["txs"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        retries: typing.Union[MetaOapg.properties.retries, decimal.Decimal, int, float, ],
        streamId: typing.Union[MetaOapg.properties.streamId, str, ],
        chainId: typing.Union[MetaOapg.properties.chainId, str, ],
        abi: typing.Union[MetaOapg.properties.abi, list, tuple, ],
        block: 'Block',
        txsInternal: typing.Union[MetaOapg.properties.txsInternal, list, tuple, ],
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        confirmed: typing.Union[MetaOapg.properties.confirmed, bool, ],
        logs: typing.Union[MetaOapg.properties.logs, list, tuple, ],
        txs: typing.Union[MetaOapg.properties.txs, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'WebhookTypesIWebhookUnParsed':
        return super().__new__(
            cls,
            *_args,
            retries=retries,
            streamId=streamId,
            chainId=chainId,
            abi=abi,
            block=block,
            txsInternal=txsInternal,
            tag=tag,
            confirmed=confirmed,
            logs=logs,
            txs=txs,
            _configuration=_configuration,
        )

from openapi_streams.model.abi_item import AbiItem
from openapi_streams.model.block import Block
from openapi_streams.model.internal_transaction import InternalTransaction
from openapi_streams.model.log import Log
from openapi_streams.model.transaction import Transaction



from .balance import balance
from .block import block
from .defi import defi
from .events import events
from .ipfs import ipfs
from .nft import nft
from .resolve import resolve
from .token import token
from .transaction import transaction
from .utils import utils



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from openapi_evm_api import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401

from openapi_evm_api.model.nft_metadata_collection import NftMetadataCollection
from openapi_evm_api.model.chain_list import ChainList

from . import path

# Query params
ChainSchema = ChainList


class FormatSchema(
    schemas.EnumBase,
    schemas.StrSchema
):


    class MetaOapg:
        enum_value_to_name = {
            "decimal": "DECIMAL",
            "hex": "HEX",
        }
    
    @schemas.classproperty
    def DECIMAL(cls):
        return cls("decimal")
    
    @schemas.classproperty
    def HEX(cls):
        return cls("hex")


class QSchema(
    schemas.StrSchema
):


    class MetaOapg:
        max_length = 256
        min_length = 3


class FilterSchema(
    schemas.EnumBase,
    schemas.StrSchema
):


    class MetaOapg:
        enum_value_to_name = {
            "name": "NAME",
            "description": "DESCRIPTION",
            "attributes": "ATTRIBUTES",
            "global": "GLOBAL",
            "name,description": "NAMEDESCRIPTION",
            "name,attributes": "NAMEATTRIBUTES",
            "description,attributes": "DESCRIPTIONATTRIBUTES",
            "name,description,attributes": "NAMEDESCRIPTIONATTRIBUTES",
        }
    
    @schemas.classproperty
    def NAME(cls):
        return cls("name")
    
    @schemas.classproperty
    def DESCRIPTION(cls):
        return cls("description")
    
    @schemas.classproperty
    def ATTRIBUTES(cls):
        return cls("attributes")
    
    @schemas.classproperty
    def GLOBAL(cls):
        return cls("global")
    
    @schemas.classproperty
    def NAMEDESCRIPTION(cls):
        return cls("name,description")
    
    @schemas.classproperty
    def NAMEATTRIBUTES(cls):
        return cls("name,attributes")
    
    @schemas.classproperty
    def DESCRIPTIONATTRIBUTES(cls):
        return cls("description,attributes")
    
    @schemas.classproperty
    def NAMEDESCRIPTIONATTRIBUTES(cls):
        return cls("name,description,attributes")


class FromBlockSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0


class ToBlockSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0
FromDateSchema = schemas.StrSchema
ToDateSchema = schemas.StrSchema


class AddressesSchema(
    schemas.ListSchema
):


    class MetaOapg:
        max_items = 10
        items = schemas.StrSchema

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AddressesSchema':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)
CursorSchema = schemas.StrSchema


class LimitSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
        'q': typing.Union[QSchema, str, ],
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'chain': typing.Union[ChainSchema, ],
        'format': typing.Union[FormatSchema, str, ],
        'filter': typing.Union[FilterSchema, str, ],
        'from_block': typing.Union[FromBlockSchema, decimal.Decimal, int, ],
        'to_block': typing.Union[ToBlockSchema, decimal.Decimal, int, ],
        'from_date': typing.Union[FromDateSchema, str, ],
        'to_date': typing.Union[ToDateSchema, str, ],
        'addresses': typing.Union[AddressesSchema, list, tuple, ],
        'cursor': typing.Union[CursorSchema, str, ],
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_chain = api_client.QueryParameter(
    name="chain",
    style=api_client.ParameterStyle.FORM,
    schema=ChainSchema,
    explode=True,
)
request_query_format = api_client.QueryParameter(
    name="format",
    style=api_client.ParameterStyle.FORM,
    schema=FormatSchema,
    explode=True,
)
request_query_q = api_client.QueryParameter(
    name="q",
    style=api_client.ParameterStyle.FORM,
    schema=QSchema,
    required=True,
    explode=True,
)
request_query_filter = api_client.QueryParameter(
    name="filter",
    style=api_client.ParameterStyle.FORM,
    schema=FilterSchema,
    explode=True,
)
request_query_from_block = api_client.QueryParameter(
    name="from_block",
    style=api_client.ParameterStyle.FORM,
    schema=FromBlockSchema,
    explode=True,
)
request_query_to_block = api_client.QueryParameter(
    name="to_block",
    style=api_client.ParameterStyle.FORM,
    schema=ToBlockSchema,
    explode=True,
)
request_query_from_date = api_client.QueryParameter(
    name="from_date",
    style=api_client.ParameterStyle.FORM,
    schema=FromDateSchema,
    explode=True,
)
request_query_to_date = api_client.QueryParameter(
    name="to_date",
    style=api_client.ParameterStyle.FORM,
    schema=ToDateSchema,
    explode=True,
)
request_query_addresses = api_client.QueryParameter(
    name="addresses",
    style=api_client.ParameterStyle.FORM,
    schema=AddressesSchema,
    explode=True,
)
request_query_cursor = api_client.QueryParameter(
    name="cursor",
    style=api_client.ParameterStyle.FORM,
    schema=CursorSchema,
    explode=True,
)
request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
_auth = [
    'ApiKeyAuth',
]
SchemaFor200ResponseBodyApplicationJson = NftMetadataCollection


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _search_nfts_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _search_nfts_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _search_nfts_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _search_nfts_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Search NFTs
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_chain,
            request_query_format,
            request_query_q,
            request_query_filter,
            request_query_from_block,
            request_query_to_block,
            request_query_from_date,
            request_query_to_date,
            request_query_addresses,
            request_query_cursor,
            request_query_limit,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class SearchNfts(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def search_nfts(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def search_nfts(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def search_nfts(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def search_nfts(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._search_nfts_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._search_nfts_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class Log(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "topic1",
            "topic2",
            "address",
            "logIndex",
            "topic0",
            "data",
            "topic3",
            "transactionHash",
        }
        
        class properties:
            logIndex = schemas.StrSchema
            transactionHash = schemas.StrSchema
            address = schemas.StrSchema
            data = schemas.StrSchema
            
            
            class topic0(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'topic0':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class topic1(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'topic1':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class topic2(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'topic2':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class topic3(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'topic3':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )
            
            
            class triggers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['TriggerOutput']:
                        return TriggerOutput
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['TriggerOutput'], typing.List['TriggerOutput']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'triggers':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'TriggerOutput':
                    return super().__getitem__(i)
            __annotations__ = {
                "logIndex": logIndex,
                "transactionHash": transactionHash,
                "address": address,
                "data": data,
                "topic0": topic0,
                "topic1": topic1,
                "topic2": topic2,
                "topic3": topic3,
                "triggers": triggers,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    topic1: MetaOapg.properties.topic1
    topic2: MetaOapg.properties.topic2
    address: MetaOapg.properties.address
    logIndex: MetaOapg.properties.logIndex
    topic0: MetaOapg.properties.topic0
    data: MetaOapg.properties.data
    topic3: MetaOapg.properties.topic3
    transactionHash: MetaOapg.properties.transactionHash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic1"]) -> MetaOapg.properties.topic1: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic2"]) -> MetaOapg.properties.topic2: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logIndex"]) -> MetaOapg.properties.logIndex: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic3"]) -> MetaOapg.properties.topic3: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactionHash"]) -> MetaOapg.properties.transactionHash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["triggers"]) -> MetaOapg.properties.triggers: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["topic1"], typing_extensions.Literal["topic2"], typing_extensions.Literal["address"], typing_extensions.Literal["logIndex"], typing_extensions.Literal["topic0"], typing_extensions.Literal["data"], typing_extensions.Literal["topic3"], typing_extensions.Literal["transactionHash"], typing_extensions.Literal["triggers"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic1"]) -> MetaOapg.properties.topic1: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic2"]) -> MetaOapg.properties.topic2: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logIndex"]) -> MetaOapg.properties.logIndex: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic3"]) -> MetaOapg.properties.topic3: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactionHash"]) -> MetaOapg.properties.transactionHash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["triggers"]) -> typing.Union[MetaOapg.properties.triggers, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["topic1"], typing_extensions.Literal["topic2"], typing_extensions.Literal["address"], typing_extensions.Literal["logIndex"], typing_extensions.Literal["topic0"], typing_extensions.Literal["data"], typing_extensions.Literal["topic3"], typing_extensions.Literal["transactionHash"], typing_extensions.Literal["triggers"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        topic1: typing.Union[MetaOapg.properties.topic1, None, str, ],
        topic2: typing.Union[MetaOapg.properties.topic2, None, str, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        logIndex: typing.Union[MetaOapg.properties.logIndex, str, ],
        topic0: typing.Union[MetaOapg.properties.topic0, None, str, ],
        data: typing.Union[MetaOapg.properties.data, str, ],
        topic3: typing.Union[MetaOapg.properties.topic3, None, str, ],
        transactionHash: typing.Union[MetaOapg.properties.transactionHash, str, ],
        triggers: typing.Union[MetaOapg.properties.triggers, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Log':
        return super().__new__(
            cls,
            *_args,
            topic1=topic1,
            topic2=topic2,
            address=address,
            logIndex=logIndex,
            topic0=topic0,
            data=data,
            topic3=topic3,
            transactionHash=transactionHash,
            triggers=triggers,
            _configuration=_configuration,
        )

from openapi_streams.model.trigger_output import TriggerOutput



import json
from .api_instance import get_api_instance
from openapi_auth.paths.challenge_verify_evm.post import SchemaForRequestBodyApplicationJson


def verify_challenge_evm(api_key: str, body: SchemaForRequestBodyApplicationJson):
    api_instance = get_api_instance(api_key)

    api_response = api_instance.verify_challenge_evm(
        body=body,
        accept_content_types='application/json; charset=utf-8',
        skip_deserialization=True
    )

    return json.loads(api_response.response.data)




# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from openapi_auth.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_auth.model.evm_challenge_request_dto import EvmChallengeRequestDto
from openapi_auth.model.evm_challenge_response_dto import EvmChallengeResponseDto
from openapi_auth.model.evm_complete_challenge_request_dto import EvmCompleteChallengeRequestDto
from openapi_auth.model.evm_complete_challenge_response_dto import EvmCompleteChallengeResponseDto
from openapi_auth.model.solana_challenge_request_dto import SolanaChallengeRequestDto
from openapi_auth.model.solana_challenge_response_dto import SolanaChallengeResponseDto
from openapi_auth.model.solana_complete_challenge_request_dto import SolanaCompleteChallengeRequestDto
from openapi_auth.model.solana_complete_challenge_response_dto import SolanaCompleteChallengeResponseDto



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Block(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "gas_used",
            "sha3_uncles",
            "transaction_count",
            "receipts_root",
            "total_difficulty",
            "transactions",
            "nonce",
            "miner",
            "difficulty",
            "number",
            "logs_bloom",
            "gas_limit",
            "size",
            "extra_data",
            "transactions_root",
            "hash",
            "parent_hash",
            "state_root",
            "timestamp",
        }
        
        class properties:
            timestamp = schemas.StrSchema
            number = schemas.StrSchema
            hash = schemas.StrSchema
            parent_hash = schemas.StrSchema
            nonce = schemas.StrSchema
            sha3_uncles = schemas.StrSchema
            logs_bloom = schemas.StrSchema
            transactions_root = schemas.StrSchema
            state_root = schemas.StrSchema
            receipts_root = schemas.StrSchema
            miner = schemas.StrSchema
            difficulty = schemas.StrSchema
            total_difficulty = schemas.StrSchema
            size = schemas.StrSchema
            extra_data = schemas.StrSchema
            gas_limit = schemas.StrSchema
            gas_used = schemas.StrSchema
            transaction_count = schemas.StrSchema
            
            
            class transactions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['BlockTransaction']:
                        return BlockTransaction
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['BlockTransaction'], typing.List['BlockTransaction']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'transactions':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'BlockTransaction':
                    return super().__getitem__(i)
            __annotations__ = {
                "timestamp": timestamp,
                "number": number,
                "hash": hash,
                "parent_hash": parent_hash,
                "nonce": nonce,
                "sha3_uncles": sha3_uncles,
                "logs_bloom": logs_bloom,
                "transactions_root": transactions_root,
                "state_root": state_root,
                "receipts_root": receipts_root,
                "miner": miner,
                "difficulty": difficulty,
                "total_difficulty": total_difficulty,
                "size": size,
                "extra_data": extra_data,
                "gas_limit": gas_limit,
                "gas_used": gas_used,
                "transaction_count": transaction_count,
                "transactions": transactions,
            }

    
    gas_used: MetaOapg.properties.gas_used
    sha3_uncles: MetaOapg.properties.sha3_uncles
    transaction_count: MetaOapg.properties.transaction_count
    receipts_root: MetaOapg.properties.receipts_root
    total_difficulty: MetaOapg.properties.total_difficulty
    transactions: MetaOapg.properties.transactions
    nonce: MetaOapg.properties.nonce
    miner: MetaOapg.properties.miner
    difficulty: MetaOapg.properties.difficulty
    number: MetaOapg.properties.number
    logs_bloom: MetaOapg.properties.logs_bloom
    gas_limit: MetaOapg.properties.gas_limit
    size: MetaOapg.properties.size
    extra_data: MetaOapg.properties.extra_data
    transactions_root: MetaOapg.properties.transactions_root
    hash: MetaOapg.properties.hash
    parent_hash: MetaOapg.properties.parent_hash
    state_root: MetaOapg.properties.state_root
    timestamp: MetaOapg.properties.timestamp
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["number"]) -> MetaOapg.properties.number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parent_hash"]) -> MetaOapg.properties.parent_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sha3_uncles"]) -> MetaOapg.properties.sha3_uncles: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logs_bloom"]) -> MetaOapg.properties.logs_bloom: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactions_root"]) -> MetaOapg.properties.transactions_root: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state_root"]) -> MetaOapg.properties.state_root: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["receipts_root"]) -> MetaOapg.properties.receipts_root: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["miner"]) -> MetaOapg.properties.miner: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["difficulty"]) -> MetaOapg.properties.difficulty: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total_difficulty"]) -> MetaOapg.properties.total_difficulty: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["size"]) -> MetaOapg.properties.size: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["extra_data"]) -> MetaOapg.properties.extra_data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_limit"]) -> MetaOapg.properties.gas_limit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_used"]) -> MetaOapg.properties.gas_used: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_count"]) -> MetaOapg.properties.transaction_count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["timestamp", "number", "hash", "parent_hash", "nonce", "sha3_uncles", "logs_bloom", "transactions_root", "state_root", "receipts_root", "miner", "difficulty", "total_difficulty", "size", "extra_data", "gas_limit", "gas_used", "transaction_count", "transactions", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["number"]) -> MetaOapg.properties.number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parent_hash"]) -> MetaOapg.properties.parent_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nonce"]) -> MetaOapg.properties.nonce: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sha3_uncles"]) -> MetaOapg.properties.sha3_uncles: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logs_bloom"]) -> MetaOapg.properties.logs_bloom: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactions_root"]) -> MetaOapg.properties.transactions_root: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state_root"]) -> MetaOapg.properties.state_root: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["receipts_root"]) -> MetaOapg.properties.receipts_root: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["miner"]) -> MetaOapg.properties.miner: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["difficulty"]) -> MetaOapg.properties.difficulty: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total_difficulty"]) -> MetaOapg.properties.total_difficulty: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["size"]) -> MetaOapg.properties.size: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["extra_data"]) -> MetaOapg.properties.extra_data: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_limit"]) -> MetaOapg.properties.gas_limit: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_used"]) -> MetaOapg.properties.gas_used: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_count"]) -> MetaOapg.properties.transaction_count: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["timestamp", "number", "hash", "parent_hash", "nonce", "sha3_uncles", "logs_bloom", "transactions_root", "state_root", "receipts_root", "miner", "difficulty", "total_difficulty", "size", "extra_data", "gas_limit", "gas_used", "transaction_count", "transactions", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        gas_used: typing.Union[MetaOapg.properties.gas_used, str, ],
        sha3_uncles: typing.Union[MetaOapg.properties.sha3_uncles, str, ],
        transaction_count: typing.Union[MetaOapg.properties.transaction_count, str, ],
        receipts_root: typing.Union[MetaOapg.properties.receipts_root, str, ],
        total_difficulty: typing.Union[MetaOapg.properties.total_difficulty, str, ],
        transactions: typing.Union[MetaOapg.properties.transactions, list, tuple, ],
        nonce: typing.Union[MetaOapg.properties.nonce, str, ],
        miner: typing.Union[MetaOapg.properties.miner, str, ],
        difficulty: typing.Union[MetaOapg.properties.difficulty, str, ],
        number: typing.Union[MetaOapg.properties.number, str, ],
        logs_bloom: typing.Union[MetaOapg.properties.logs_bloom, str, ],
        gas_limit: typing.Union[MetaOapg.properties.gas_limit, str, ],
        size: typing.Union[MetaOapg.properties.size, str, ],
        extra_data: typing.Union[MetaOapg.properties.extra_data, str, ],
        transactions_root: typing.Union[MetaOapg.properties.transactions_root, str, ],
        hash: typing.Union[MetaOapg.properties.hash, str, ],
        parent_hash: typing.Union[MetaOapg.properties.parent_hash, str, ],
        state_root: typing.Union[MetaOapg.properties.state_root, str, ],
        timestamp: typing.Union[MetaOapg.properties.timestamp, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Block':
        return super().__new__(
            cls,
            *_args,
            gas_used=gas_used,
            sha3_uncles=sha3_uncles,
            transaction_count=transaction_count,
            receipts_root=receipts_root,
            total_difficulty=total_difficulty,
            transactions=transactions,
            nonce=nonce,
            miner=miner,
            difficulty=difficulty,
            number=number,
            logs_bloom=logs_bloom,
            gas_limit=gas_limit,
            size=size,
            extra_data=extra_data,
            transactions_root=transactions_root,
            hash=hash,
            parent_hash=parent_hash,
            state_root=state_root,
            timestamp=timestamp,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.block_transaction import BlockTransaction



# coding: utf-8

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_auth import schemas  # noqa: F401


class SolanaChallengeResponseDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "profileId",
            "id",
            "message",
        }
        
        class properties:
            
            
            class id(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 8
                    regex=[{
                        'pattern': r'^[a-zA-Z0-9]{8,64}$',  # noqa: E501
                    }]
            message = schemas.StrSchema
            profileId = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "message": message,
                "profileId": profileId,
            }
    
    profileId: MetaOapg.properties.profileId
    id: MetaOapg.properties.id
    message: MetaOapg.properties.message
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["profileId"]) -> MetaOapg.properties.profileId: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "message", "profileId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["profileId"]) -> MetaOapg.properties.profileId: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "message", "profileId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        profileId: typing.Union[MetaOapg.properties.profileId, str, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        message: typing.Union[MetaOapg.properties.message, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SolanaChallengeResponseDto':
        return super().__new__(
            cls,
            *_args,
            profileId=profileId,
            id=id,
            message=message,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class ReservesCollection(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            
            
            class token0(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        address = schemas.StrSchema
                        name = schemas.StrSchema
                        symbol = schemas.StrSchema
                        decimals = schemas.StrSchema
                        logo = schemas.StrSchema
                        logo_hash = schemas.StrSchema
                        thumbnail = schemas.StrSchema
                        block_number = schemas.StrSchema
                        validated = schemas.NumberSchema
                        created_at = schemas.StrSchema
                        __annotations__ = {
                            "address": address,
                            "name": name,
                            "symbol": symbol,
                            "decimals": decimals,
                            "logo": logo,
                            "logo_hash": logo_hash,
                            "thumbnail": thumbnail,
                            "block_number": block_number,
                            "validated": validated,
                            "created_at": created_at,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["logo_hash"]) -> MetaOapg.properties.logo_hash: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["thumbnail"]) -> MetaOapg.properties.thumbnail: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["validated"]) -> MetaOapg.properties.validated: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "name", "symbol", "decimals", "logo", "logo_hash", "thumbnail", "block_number", "validated", "created_at", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> typing.Union[MetaOapg.properties.symbol, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["decimals"]) -> typing.Union[MetaOapg.properties.decimals, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> typing.Union[MetaOapg.properties.logo, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["logo_hash"]) -> typing.Union[MetaOapg.properties.logo_hash, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["thumbnail"]) -> typing.Union[MetaOapg.properties.thumbnail, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> typing.Union[MetaOapg.properties.block_number, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["validated"]) -> typing.Union[MetaOapg.properties.validated, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "name", "symbol", "decimals", "logo", "logo_hash", "thumbnail", "block_number", "validated", "created_at", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
                    name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                    symbol: typing.Union[MetaOapg.properties.symbol, str, schemas.Unset] = schemas.unset,
                    decimals: typing.Union[MetaOapg.properties.decimals, str, schemas.Unset] = schemas.unset,
                    logo: typing.Union[MetaOapg.properties.logo, str, schemas.Unset] = schemas.unset,
                    logo_hash: typing.Union[MetaOapg.properties.logo_hash, str, schemas.Unset] = schemas.unset,
                    thumbnail: typing.Union[MetaOapg.properties.thumbnail, str, schemas.Unset] = schemas.unset,
                    block_number: typing.Union[MetaOapg.properties.block_number, str, schemas.Unset] = schemas.unset,
                    validated: typing.Union[MetaOapg.properties.validated, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
                    created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'token0':
                    return super().__new__(
                        cls,
                        *_args,
                        address=address,
                        name=name,
                        symbol=symbol,
                        decimals=decimals,
                        logo=logo,
                        logo_hash=logo_hash,
                        thumbnail=thumbnail,
                        block_number=block_number,
                        validated=validated,
                        created_at=created_at,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class token1(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        address = schemas.StrSchema
                        name = schemas.StrSchema
                        symbol = schemas.StrSchema
                        decimals = schemas.StrSchema
                        logo = schemas.StrSchema
                        logo_hash = schemas.StrSchema
                        thumbnail = schemas.StrSchema
                        block_number = schemas.StrSchema
                        validated = schemas.NumberSchema
                        created_at = schemas.StrSchema
                        __annotations__ = {
                            "address": address,
                            "name": name,
                            "symbol": symbol,
                            "decimals": decimals,
                            "logo": logo,
                            "logo_hash": logo_hash,
                            "thumbnail": thumbnail,
                            "block_number": block_number,
                            "validated": validated,
                            "created_at": created_at,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["logo_hash"]) -> MetaOapg.properties.logo_hash: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["thumbnail"]) -> MetaOapg.properties.thumbnail: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["validated"]) -> MetaOapg.properties.validated: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "name", "symbol", "decimals", "logo", "logo_hash", "thumbnail", "block_number", "validated", "created_at", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> typing.Union[MetaOapg.properties.symbol, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["decimals"]) -> typing.Union[MetaOapg.properties.decimals, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> typing.Union[MetaOapg.properties.logo, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["logo_hash"]) -> typing.Union[MetaOapg.properties.logo_hash, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["thumbnail"]) -> typing.Union[MetaOapg.properties.thumbnail, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> typing.Union[MetaOapg.properties.block_number, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["validated"]) -> typing.Union[MetaOapg.properties.validated, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "name", "symbol", "decimals", "logo", "logo_hash", "thumbnail", "block_number", "validated", "created_at", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
                    name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                    symbol: typing.Union[MetaOapg.properties.symbol, str, schemas.Unset] = schemas.unset,
                    decimals: typing.Union[MetaOapg.properties.decimals, str, schemas.Unset] = schemas.unset,
                    logo: typing.Union[MetaOapg.properties.logo, str, schemas.Unset] = schemas.unset,
                    logo_hash: typing.Union[MetaOapg.properties.logo_hash, str, schemas.Unset] = schemas.unset,
                    thumbnail: typing.Union[MetaOapg.properties.thumbnail, str, schemas.Unset] = schemas.unset,
                    block_number: typing.Union[MetaOapg.properties.block_number, str, schemas.Unset] = schemas.unset,
                    validated: typing.Union[MetaOapg.properties.validated, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
                    created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'token1':
                    return super().__new__(
                        cls,
                        *_args,
                        address=address,
                        name=name,
                        symbol=symbol,
                        decimals=decimals,
                        logo=logo,
                        logo_hash=logo_hash,
                        thumbnail=thumbnail,
                        block_number=block_number,
                        validated=validated,
                        created_at=created_at,
                        _configuration=_configuration,
                        **kwargs,
                    )
            pairAddress = schemas.StrSchema
            __annotations__ = {
                "token0": token0,
                "token1": token1,
                "pairAddress": pairAddress,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token0"]) -> MetaOapg.properties.token0: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token1"]) -> MetaOapg.properties.token1: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pairAddress"]) -> MetaOapg.properties.pairAddress: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["token0", "token1", "pairAddress", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token0"]) -> typing.Union[MetaOapg.properties.token0, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token1"]) -> typing.Union[MetaOapg.properties.token1, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pairAddress"]) -> typing.Union[MetaOapg.properties.pairAddress, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["token0", "token1", "pairAddress", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        token0: typing.Union[MetaOapg.properties.token0, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        token1: typing.Union[MetaOapg.properties.token1, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        pairAddress: typing.Union[MetaOapg.properties.pairAddress, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ReservesCollection':
        return super().__new__(
            cls,
            *_args,
            token0=token0,
            token1=token1,
            pairAddress=pairAddress,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

# flake8: noqa

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from openapi_evm_api.api_client import ApiClient

# import Configuration
from openapi_evm_api.configuration import Configuration

# import exceptions
from openapi_evm_api.exceptions import OpenApiException
from openapi_evm_api.exceptions import ApiAttributeError
from openapi_evm_api.exceptions import ApiTypeError
from openapi_evm_api.exceptions import ApiValueError
from openapi_evm_api.exceptions import ApiKeyError
from openapi_evm_api.exceptions import ApiException



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class BlockDate(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "date",
            "block",
            "timestamp",
        }
        
        class properties:
            date = schemas.StrSchema
            block = schemas.NumberSchema
            timestamp = schemas.NumberSchema
            block_timestamp = schemas.NumberSchema
            block_hash = schemas.StrSchema
            parent_hash = schemas.StrSchema
            __annotations__ = {
                "date": date,
                "block": block,
                "timestamp": timestamp,
                "block_timestamp": block_timestamp,
                "block_hash": block_hash,
                "parent_hash": parent_hash,
            }

    
    date: MetaOapg.properties.date
    block: MetaOapg.properties.block
    timestamp: MetaOapg.properties.timestamp
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["date"]) -> MetaOapg.properties.date: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block"]) -> MetaOapg.properties.block: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parent_hash"]) -> MetaOapg.properties.parent_hash: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["date", "block", "timestamp", "block_timestamp", "block_hash", "parent_hash", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["date"]) -> MetaOapg.properties.date: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block"]) -> MetaOapg.properties.block: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> typing.Union[MetaOapg.properties.block_timestamp, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> typing.Union[MetaOapg.properties.block_hash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parent_hash"]) -> typing.Union[MetaOapg.properties.parent_hash, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["date", "block", "timestamp", "block_timestamp", "block_hash", "parent_hash", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        date: typing.Union[MetaOapg.properties.date, str, ],
        block: typing.Union[MetaOapg.properties.block, decimal.Decimal, int, float, ],
        timestamp: typing.Union[MetaOapg.properties.timestamp, decimal.Decimal, int, float, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, decimal.Decimal, int, float, schemas.Unset] = schemas.unset,
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, schemas.Unset] = schemas.unset,
        parent_hash: typing.Union[MetaOapg.properties.parent_hash, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BlockDate':
        return super().__new__(
            cls,
            *_args,
            date=date,
            block=block,
            timestamp=timestamp,
            block_timestamp=block_timestamp,
            block_hash=block_hash,
            parent_hash=parent_hash,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Trade(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "token_ids",
            "buyer_address",
            "price",
            "block_timestamp",
            "block_hash",
            "block_number",
            "marketplace_address",
            "token_address",
            "transaction_index",
            "seller_address",
            "transaction_hash",
        }
        
        class properties:
            transaction_hash = schemas.StrSchema
            transaction_index = schemas.StrSchema
            
            
            class token_ids(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'token_ids':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            seller_address = schemas.StrSchema
            buyer_address = schemas.StrSchema
            marketplace_address = schemas.StrSchema
            price = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            block_number = schemas.StrSchema
            block_hash = schemas.StrSchema
            __annotations__ = {
                "transaction_hash": transaction_hash,
                "transaction_index": transaction_index,
                "token_ids": token_ids,
                "seller_address": seller_address,
                "buyer_address": buyer_address,
                "marketplace_address": marketplace_address,
                "price": price,
                "block_timestamp": block_timestamp,
                "block_number": block_number,
                "block_hash": block_hash,
            }

    
    token_ids: MetaOapg.properties.token_ids
    buyer_address: MetaOapg.properties.buyer_address
    price: MetaOapg.properties.price
    block_timestamp: MetaOapg.properties.block_timestamp
    block_hash: MetaOapg.properties.block_hash
    block_number: MetaOapg.properties.block_number
    marketplace_address: MetaOapg.properties.marketplace_address
    token_address: schemas.AnyTypeSchema
    transaction_index: MetaOapg.properties.transaction_index
    seller_address: MetaOapg.properties.seller_address
    transaction_hash: MetaOapg.properties.transaction_hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_ids"]) -> MetaOapg.properties.token_ids: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["seller_address"]) -> MetaOapg.properties.seller_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["buyer_address"]) -> MetaOapg.properties.buyer_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["marketplace_address"]) -> MetaOapg.properties.marketplace_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["transaction_hash", "transaction_index", "token_ids", "seller_address", "buyer_address", "marketplace_address", "price", "block_timestamp", "block_number", "block_hash", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_ids"]) -> MetaOapg.properties.token_ids: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["seller_address"]) -> MetaOapg.properties.seller_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["buyer_address"]) -> MetaOapg.properties.buyer_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["marketplace_address"]) -> MetaOapg.properties.marketplace_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["transaction_hash", "transaction_index", "token_ids", "seller_address", "buyer_address", "marketplace_address", "price", "block_timestamp", "block_number", "block_hash", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        token_ids: typing.Union[MetaOapg.properties.token_ids, list, tuple, ],
        buyer_address: typing.Union[MetaOapg.properties.buyer_address, str, ],
        price: typing.Union[MetaOapg.properties.price, str, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        marketplace_address: typing.Union[MetaOapg.properties.marketplace_address, str, ],
        token_address: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        transaction_index: typing.Union[MetaOapg.properties.transaction_index, str, ],
        seller_address: typing.Union[MetaOapg.properties.seller_address, str, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Trade':
        return super().__new__(
            cls,
            *_args,
            token_ids=token_ids,
            buyer_address=buyer_address,
            price=price,
            block_timestamp=block_timestamp,
            block_hash=block_hash,
            block_number=block_number,
            marketplace_address=marketplace_address,
            token_address=token_address,
            transaction_index=transaction_index,
            seller_address=seller_address,
            transaction_hash=transaction_hash,
            _configuration=_configuration,
            **kwargs,
        )



import typing_extensions

from openapi_auth.apis.tags import TagValues
from openapi_auth.apis.tags.challenge_api import ChallengeApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.CHALLENGE: ChallengeApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.CHALLENGE: ChallengeApi,
    }
)



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class SettingsTypesSettingsModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def region() -> typing.Type['SettingsRegion']:
                return SettingsRegion
            __annotations__ = {
                "region": region,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["region"]) -> 'SettingsRegion': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["region"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["region"]) -> typing.Union['SettingsRegion', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["region"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        region: typing.Union['SettingsRegion', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SettingsTypesSettingsModel':
        return super().__new__(
            cls,
            *_args,
            region=region,
            _configuration=_configuration,
        )

from openapi_streams.model.settings_region import SettingsRegion



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from openapi_evm_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_evm_api.model.block import Block
from openapi_evm_api.model.block_date import BlockDate
from openapi_evm_api.model.block_transaction import BlockTransaction
from openapi_evm_api.model.chain_list import ChainList
from openapi_evm_api.model.endpoint_weights import EndpointWeights
from openapi_evm_api.model.ens import Ens
from openapi_evm_api.model.erc20_allowance import Erc20Allowance
from openapi_evm_api.model.erc20_metadata import Erc20Metadata
from openapi_evm_api.model.erc20_price import Erc20Price
from openapi_evm_api.model.erc20_token_balance import Erc20TokenBalance
from openapi_evm_api.model.erc20_transaction import Erc20Transaction
from openapi_evm_api.model.erc20_transaction_collection import Erc20TransactionCollection
from openapi_evm_api.model.erc721_metadata import Erc721Metadata
from openapi_evm_api.model.get_multiple_nfts_dto import GetMultipleNftsDto
from openapi_evm_api.model.historical_nft_transfer import HistoricalNftTransfer
from openapi_evm_api.model.ipfs_file import IpfsFile
from openapi_evm_api.model.ipfs_file_request import IpfsFileRequest
from openapi_evm_api.model.log import Log
from openapi_evm_api.model.log_collection import LogCollection
from openapi_evm_api.model.log_event import LogEvent
from openapi_evm_api.model.log_event_by_address import LogEventByAddress
from openapi_evm_api.model.metadata_resync import MetadataResync
from openapi_evm_api.model.native_balance import NativeBalance
from openapi_evm_api.model.native_erc20_price import NativeErc20Price
from openapi_evm_api.model.nft import Nft
from openapi_evm_api.model.nft_collection import NftCollection
from openapi_evm_api.model.nft_collections import NftCollections
from openapi_evm_api.model.nft_contract_metadata import NftContractMetadata
from openapi_evm_api.model.nft_contract_metadata_collection import NftContractMetadataCollection
from openapi_evm_api.model.nft_metadata import NftMetadata
from openapi_evm_api.model.nft_metadata_collection import NftMetadataCollection
from openapi_evm_api.model.nft_owner import NftOwner
from openapi_evm_api.model.nft_owner_collection import NftOwnerCollection
from openapi_evm_api.model.nft_transfer import NftTransfer
from openapi_evm_api.model.nft_transfer_collection import NftTransferCollection
from openapi_evm_api.model.nft_wallet_collections import NftWalletCollections
from openapi_evm_api.model.normalized_metadata import NormalizedMetadata
from openapi_evm_api.model.normalized_metadata_attribute import NormalizedMetadataAttribute
from openapi_evm_api.model.reserves_collection import ReservesCollection
from openapi_evm_api.model.reserves_pair import ReservesPair
from openapi_evm_api.model.resolve import Resolve
from openapi_evm_api.model.run_contract_dto import RunContractDto
from openapi_evm_api.model.token_item import TokenItem
from openapi_evm_api.model.trade import Trade
from openapi_evm_api.model.trade_collection import TradeCollection
from openapi_evm_api.model.transaction import Transaction
from openapi_evm_api.model.transaction_collection import TransactionCollection
from openapi_evm_api.model.transaction_collection_verbose import TransactionCollectionVerbose
from openapi_evm_api.model.web3version import Web3version
